﻿// <copyright company="PEER Group GmbH">
//    Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System.Windows;
using Infragistics.Controls.Menus;

namespace EafClient.Core.Behaviors
{
	/// <summary>
	/// Represents an extension class that facilitate the use of common capabilities in
	/// the XamDataTree related behaviors.
	/// </summary>
	internal static class XamDataTreeBehaviorExtensions
	{
		/// <summary>
		/// Gets the original source XamDataTreeNode element for an event from the specified
		/// <see cref="RoutedEventArgs"/> event arguments.
		/// </summary>
		/// <param name="args">
		/// The <see cref="RoutedEventArgs"/> instance containing the event data.</param>
		/// <returns>
		/// <c>true</c> if the specified routed event occurred on a XamDataTreeNode; otherwise, <c>false</c>.
		/// </returns>
		internal static XamDataTreeNode GetSourceXamDataTreeNode(this RoutedEventArgs args)
		{
			if (args == null)
				return null;

			var source = args.OriginalSource as DependencyObject;

			if (source == null)
				return null;

			// if source is any other type than XamDataTreeNodeControl, such as a TextBlock,
			// get its parent object which is supposed to be a XamDataTreeNodeControl object.
			if (!(source is XamDataTreeNodeControl))
			{
				var xamDataTreeNode = Infragistics.Windows.Utilities.GetAncestorFromType(
					source, typeof(XamDataTreeNodeControl), false) as XamDataTreeNodeControl;

				return xamDataTreeNode?.Node;
			}

			// if source is a XamDataTreeNodeControl object, simply return its Node object.
			if (source is XamDataTreeNodeControl)
			{
				return ((XamDataTreeNodeControl)source).Node;
			}

			return null;
		}

		/// <summary>
		/// Selects the specified XamDataTreeNode node.
		/// </summary>
		/// <param name="node">The node that should be selected.</param>
		internal static void Select(this XamDataTreeNode node)
		{
			node.IsSelected = true;
			node.IsActive = true;
		}
	}
}
