﻿// <copyright company="PEER Group GmbH">
//    Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

namespace SpreadsheetOwnerErrorSampleV3.Core.Prism
{
	/// <summary>
	/// Interface indicating that the view or view model is aware of docking.
	/// </summary>
	/// <remarks>
	/// Based on source:
	/// http://www.infragistics.com/community/blogs/blagunas/archive/2012/09/13/xamdockmanager-a-prism-regionadapter.aspx
	/// Written by Brian Lagunas.
	/// Blog: http://brianlagunas.com.
	/// Twitter: @brianlagunas.
	/// Email: blagunas@infragistics.com.
	/// </remarks>
	public interface IDockAware
	{
		/// <summary>
		/// Gets or sets the content pane header.
		/// </summary>
		string Header { get; set; }

		/// <summary>
		/// Gets a value indicating whether the associated view is allowed to close.
		/// </summary>
		bool AllowClose { get; }

		/// <summary>
		/// Gets a value indicating whether this instance is pinned.
		/// </summary>
		bool IsPinned { get; }

		/// <summary>
		/// Gets or sets a value indicating whether the document pane is selected.
		/// </summary>
		bool IsSelected { get; set; }
	}
}
