﻿// <copyright file="IWorkbook.cs" company="PEER Group GmbH">
// Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System.Collections.Generic;
using Infragistics.Controls.Grids;

namespace SpreadsheetOwnerErrorSampleV3.Interfaces
{
	/// <summary>Represents an Excel-like workbook abstraction.</summary>
	public interface IWorkbook : IEnumerable<IWorksheet>
	{
		/// <summary>Gets a spreadsheet with the specified name.</summary>
		/// <param name="name">The name of the spreadsheet.</param>
		/// <returns>The requested spreadsheet.</returns>
		IWorksheet this[string name] { get; }

		/// <summary>Applies current state of the workbook to the spreadsheet control.</summary>
		/// <param name="excelControl">Spreadsheet control to be updated.</param>
		void ApplyTo(XamSpreadsheet excelControl);

		/// <summary>Saves the content of the workbook into the specified file.</summary>
		/// <param name="fileName">Filename of the saved content.</param>
		void Save(string fileName);

		/// <summary>Gets the active Worksheet.</summary>
		/// <returns>The currently active Worksheet.</returns>
		IWorksheet GetActiveWorksheet();

		/// <summary>Gets all SheetNames of this workbook.</summary>
		/// <returns>The Names of all Worksheets.</returns>
		IEnumerable<string> GetSheetNames();

		/// <summary>Deletes the active Worksheet and moves the focus to the left.</summary>
		void DeleteActiveWorksheet();

		/// <summary>Renames the worksheet in the workbook.</summary>
		/// <param name="newName">The new name of the worksheet.</param>
		/// <param name="oldName">The current name of the worksheet.</param>
		void RenameWorksheet(string newName, string oldName);

		/// <summary>Sets the worksheet as an active one.</summary>
		/// <param name="name">Name of the worksheet to be active.</param>
		void SetActiveWorksheet(string name);
	}
}
