﻿// <copyright file="IWorksheet.cs" company="PEER Group GmbH">
// Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System.Collections.Generic;

namespace SpreadsheetOwnerErrorSampleV3.Interfaces
{
	/// <summary>Represents a worksheet abstraction.</summary>
	public interface IWorksheet
	{
		/// <summary>
		/// Gets the worksheet cell located at the position (row, col).
		/// </summary>
		/// <param name="row">Row index of the cell.</param>
		/// <param name="col">Column index of the cell.</param>
		/// <returns>Worksheet cell implementation.</returns>
		IWorksheetCell this[int row, int col] { get; }

		/// <summary>
		/// Gets the worksheet cell located at the position specified by the row number and column name.
		/// </summary>
		/// <param name="row">Row index of the cell.</param>
		/// <param name="colName">Friendly name of the column containing the cell.</param>
		/// <returns>Worksheet cell implementation.</returns>
		IWorksheetCell this[int row, string colName] { get; }

		/// <summary>Gets the list of worksheet columns.</summary>
		IList<IWorksheetColumn> Columns { get; }

		/// <summary>Gets the list of worksheet rows.</summary>
		IList<IWorksheetRow> Rows { get; }

		/// <summary>Gets a value indicating whether the worksheet is object type sheet.</summary>
		bool IsObjectType { get; }

		/// <summary>Gets or sets the name of the worksheet.</summary>
		string Name { get; set; }

		/// <summary>
		/// Entry point of bulk row insert operation.
		/// </summary>
		void EnterBulkRowInsert();

		/// <summary>
		/// Exit point of bulk row insert operation.
		/// </summary>
		void ExitBulkRowInsert();
	}
}
