﻿// <copyright file="Spreadsheet.cs" company="PEER Group GmbH">
// Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System.Collections.Generic;
using Infragistics.Documents.Excel;
using SpreadsheetOwnerErrorSampleV3.Interfaces;

namespace SpreadsheetOwnerErrorSampleV3.SpreadsheetControl
{
	internal class Spreadsheet : IWorksheet
	{
		private readonly Worksheet mWorksheet;
		private readonly SpreadsheetRows mRows;
		private readonly SpreadsheetColumns mColumns;

		public Spreadsheet(Worksheet worksheet)
		{
			mWorksheet = worksheet;
			mColumns = new SpreadsheetColumns(worksheet);
			mRows = new SpreadsheetRows(worksheet);
		}

		public IWorksheetCell this[int row, int col]
		{
			get
			{
				CreateColumnIfNotExist(col);
				return Rows[row].Cells[col];
			}
		}

		public IWorksheetCell this[int row, string colName] => Rows[row].Cells[mColumns[colName].Index];

		public IList<IWorksheetColumn> Columns => mColumns;

		public IList<IWorksheetRow> Rows => mRows;

		public bool IsObjectType => false;

		public string Name
		{
			get => mWorksheet.Name;
			set => mWorksheet.Name = value;
		}

		public void EnterBulkRowInsert()
			=> mRows.EnterBulkRowInsert();

		public void ExitBulkRowInsert()
			=> mRows.ExitBulkRowInsert();

		private void CreateColumnIfNotExist(int col)
			=> _ = mColumns[col];
	}
}
