﻿// <copyright file="SpreadsheetCells.cs" company="PEER Group GmbH">
// Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using Infragistics.Documents.Excel;
using Microsoft.Practices.ObjectBuilder2;
using SpreadsheetOwnerErrorSampleV3.Interfaces;

namespace SpreadsheetOwnerErrorSampleV3.SpreadsheetControl
{
	internal class SpreadsheetCells : IList<IWorksheetCell>
	{
		private readonly SpreadsheetCellFactory mCellFactory;
		private readonly WorksheetRow mRow;

		private List<IWorksheetCell> mCells = new List<IWorksheetCell>();
		private Hashtable mCellsByIndex;

		public SpreadsheetCells(WorksheetRow row)
		{
			mRow = row;
			mCellFactory = new SpreadsheetCellFactory();

			mRow.Cells.ForEach(c => mCells.Add(mCellFactory.Create(c)));
			InitializeCellsByIndex();
		}

		public IWorksheetCell this[int index]
		{
			get
			{
				if (mCellsByIndex[index] is IWorksheetCell foundCell)
					return foundCell;

				var newCell = mRow.Cells[index];
				var spreadsheetCell = mCellFactory.Create(newCell);
				mCells.Add(spreadsheetCell);
				mCellsByIndex.Add(spreadsheetCell.ColumnIndex, spreadsheetCell);
				return spreadsheetCell;
			}

			set => throw new NotSupportedException();
		}

		public int Count => mCells.Count;

		public bool IsReadOnly => true;

		public void Add(IWorksheetCell item)
			=> throw new InvalidOperationException("Use this[index] operator instead.");

		public void Clear()
		{
			mCells.Clear();
			mCellsByIndex = new Hashtable();
		}

		public bool Contains(IWorksheetCell item)
			=> mCells.Contains(item);

		public void CopyTo(IWorksheetCell[] array, int arrayIndex)
			=> mCells.CopyTo(array, arrayIndex);

		public IEnumerator<IWorksheetCell> GetEnumerator()
			=> mCells.OrderBy(c => c.ColumnIndex).GetEnumerator();

		public int IndexOf(IWorksheetCell item)
			=> mCells.IndexOf(item);

		public void Insert(int index, IWorksheetCell item)
			=> throw new InvalidOperationException("Use this[index] operator instead.");

		public bool Remove(IWorksheetCell item)
			=> throw new InvalidOperationException("Remove is not allowed.");

		public void RemoveAt(int index)
			=> throw new InvalidOperationException("RemoveAt is not allowed.");

		IEnumerator IEnumerable.GetEnumerator()
			=> mCells.OrderBy(c => c.ColumnIndex).GetEnumerator();

		private void InitializeCellsByIndex()
		{
			mCellsByIndex = new Hashtable();
			mCells.ForEach(c => mCellsByIndex.Add(c.ColumnIndex, c));
		}
	}
}
