﻿// <copyright file="SpreadsheetColumns.cs" company="PEER Group GmbH">
// Copyright (c) PEER Group GmbH. All rights reserved.
// </copyright>

using System;
using System.Collections;
using System.Collections.Generic;
using System.Linq;
using Infragistics.Documents.Excel;
using Microsoft.Practices.ObjectBuilder2;
using SpreadsheetOwnerErrorSampleV3.Interfaces;

namespace SpreadsheetOwnerErrorSampleV3.SpreadsheetControl
{
	internal class SpreadsheetColumns : IList<IWorksheetColumn>
	{
		private readonly SpreadsheetColumnFactory mColumnFactory;
		private readonly Worksheet mWorksheet;
		private readonly List<IWorksheetColumn> mColumns = new List<IWorksheetColumn>();

		private Hashtable mColumnsByIndex;

		public SpreadsheetColumns(Worksheet worksheet)
		{
			mWorksheet = worksheet;
			mColumnFactory = new SpreadsheetColumnFactory();

			mWorksheet.Columns.ForEach(c => mColumns.Add(mColumnFactory.Create(c)));
			InitializeColumnsByIndex();
		}

		public IWorksheetColumn this[int index]
		{
			get
			{
				if (mColumnsByIndex[index] is IWorksheetColumn foundColumn)
					return foundColumn;

				var newColumn = mWorksheet.Columns[index];
				var spreadsheetColumn = mColumnFactory.Create(newColumn);
				mColumns.Add(spreadsheetColumn);
				mColumnsByIndex.Add(spreadsheetColumn.Index, spreadsheetColumn);
				return spreadsheetColumn;
			}

			set => throw new NotSupportedException();
		}

		public IWorksheetColumn this[string columnName]
			=> mColumns.FirstOrDefault(c => c.FriendlyName == columnName);

		public int Count => mColumns.Count;

		public bool IsReadOnly => true;

		public void Add(IWorksheetColumn item)
			=> throw new InvalidOperationException("Use this[index] operator instead.");

		public void Clear()
		{
			mColumns.Clear();
			mColumnsByIndex = new Hashtable();
		}

		public bool Contains(IWorksheetColumn item)
			=> mColumns.Contains(item);

		public void CopyTo(IWorksheetColumn[] array, int arrayIndex)
			=> mColumns.CopyTo(array, arrayIndex);

		public IEnumerator<IWorksheetColumn> GetEnumerator()
			=> mColumns.OrderBy(c => c.Index).GetEnumerator();

		public int IndexOf(IWorksheetColumn item)
			=> mColumns.IndexOf(item);

		public void Insert(int index, IWorksheetColumn item)
			=> throw new InvalidOperationException("Use this[index] operator instead.");

		public bool Remove(IWorksheetColumn item)
			=> throw new InvalidOperationException("Remove is not allowed.");

		public void RemoveAt(int index)
			=> throw new InvalidOperationException("RemoveAt is not allowed.");

		IEnumerator IEnumerable.GetEnumerator()
			=> mColumns.OrderBy(c => c.Index).GetEnumerator();

		private void InitializeColumnsByIndex()
		{
			mColumnsByIndex = new Hashtable();
			mColumns.ForEach(c => mColumnsByIndex.Add(c.Index, c));
		}
	}
}
