﻿using System;
using System.Collections.Generic;
using System.ComponentModel;
using System.Linq;
using System.Runtime.CompilerServices;
using System.Windows.Controls;
using Microsoft.Practices.Prism.Events;
using Microsoft.Practices.Prism.Regions;
using SpreadsheetOwnerErrorSampleV3.Core.Events;
using SpreadsheetOwnerErrorSampleV3.Core.Prism;
using SpreadsheetOwnerErrorSampleV3.Schema;

namespace SpreadsheetOwnerErrorSampleV3.Views
{
	/// <summary>
	/// Interaction logic for EditorViewWithSpreadsheet.xaml
	/// </summary>
	public partial class EditorViewWithSpreadsheet : UserControl, IDockAware, INavigationAware, INotifyPropertyChanged
	{
		private static int sLastId;
		private readonly int mCurrentId;
		private readonly LogNotify mLog;
		private string mSelectedValue;

		public EditorViewWithSpreadsheet(IEventAggregator eventAggregator)
		{
			mCurrentId = ++sLastId;
			mLog = new LogNotify($"WB.{mCurrentId}");
			InitializeComponent();
			Header += mCurrentId;

			RaiseEvent("ctor EditorViewWithSpreadsheet()");

			//Loaded += (sender, args) => ReloadWorkbook();
			//Initialized += (sender, args) => { };
		}

		private void ReloadWorkbook()
		{
			RaiseEvent("ReloadWorkbook");

			//SpreadSheet.Workbook = Workbook.Load("SampleSheet.xlsx");

			var schema = new EquipmentDictionaryWorkbookSchema26();
			var workbook = schema.CreateWorkbook();
			workbook.ApplyTo(SpreadSheet);
		}

		/// <inheritdoc />
		protected override void OnInitialized(EventArgs e)
		{
			base.OnInitialized(e);
			ReloadWorkbook();
		}

		/// <inheritdoc />
		public string Header { get; set; } = "Workbook";

		/// <inheritdoc />
		public bool AllowClose { get; } = true;

		/// <inheritdoc />
		public bool IsPinned { get; } = true;

		/// <inheritdoc />
		public bool IsSelected { get; set; }

		/// <inheritdoc />
		public void OnNavigatedTo(NavigationContext navigationContext)
		{
			mSelectedValue = GetListValue(navigationContext);
			if (Header.Contains(mSelectedValue))
				return;
			Header += $"- {mSelectedValue}";
			OnPropertyChanged(nameof(Header));
		}

		/// <inheritdoc />
		public bool IsNavigationTarget(NavigationContext navigationContext)
		{
			if (mSelectedValue == null)
				return false;

			var openingValue = GetListValue(navigationContext);
			RaiseEvent($"IsNavigationTarget for '{openingValue}'");
			return mSelectedValue == openingValue;
		}

		/// <inheritdoc />
		public void OnNavigatedFrom(NavigationContext navigationContext)
		{
		}

		private string GetListValue(NavigationContext navigationContext)
		{
			var parameters = navigationContext.NavigationService.Region.Context as IDictionary<string, object>;
			if (parameters == null)
				return null;

			return (string)parameters["Test"];
		}

		public event PropertyChangedEventHandler PropertyChanged;

		protected virtual void OnPropertyChanged([CallerMemberName] string propertyName = null) =>
			PropertyChanged?.Invoke(this, new PropertyChangedEventArgs(propertyName));

		private void RaiseEvent(string message) => mLog.Write(SpreadSheet, message);
	}
}
